from distutils.core import setup
setup(
  name = 'trtwn',
  packages = ['trtwn'],
  version = '0.2.0',
  description = 'My personal python package with (just for me) useful shorthands',
  author = 'Dennis Trautwein',
  author_email = 'gafwurstula@posteo.net',
  url = 'https://github.com/dennis-tra/trtwn',
  download_url = 'https://github.com/dennis-tra/trtwn/archive/0.1.tar.gz',
  keywords = [],
  install_requires=['matplotlib', 'scipy', 'numpy'],
  classifiers = [],
)
